<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>DecoderVorbisFactory</name>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="50"/>
        <source>Ogg Vorbis Plugin</source>
        <translation>Модуль Ogg Vorbis</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="53"/>
        <source>Ogg Vorbis Files</source>
        <translation>Файлы Ogg Vorbis</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="113"/>
        <source>About Ogg Vorbis Audio Plugin</source>
        <translation>Об аудио-модуле Ogg Vorbis</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="114"/>
        <source>Qmmp Ogg Vorbis Audio Plugin</source>
        <translation>Аудио-модуль Ogg Vorbis для Qmmp</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="115"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="116"/>
        <source>Source code based on mq3 progect</source>
        <translation>Исходный код основан на проекте mq3</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="61"/>
        <source>Hz</source>
        <translation>Гц</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="273"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="283"/>
        <source>Track number:</source>
        <translation>Номер трека:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="296"/>
        <source>Year:</source>
        <translation>Год:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="306"/>
        <source>Genre:</source>
        <translation>Жанр:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="316"/>
        <source>Comment:</source>
        <translation>Комментарий:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="326"/>
        <source>Album:</source>
        <translation>Альбом:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="336"/>
        <source>Artist:</source>
        <translation>Исполнитель:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="346"/>
        <source>Title:</source>
        <translation>Название:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="387"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="66"/>
        <location filename="../detailsdialog.ui" line="76"/>
        <location filename="../detailsdialog.ui" line="93"/>
        <location filename="../detailsdialog.ui" line="110"/>
        <location filename="../detailsdialog.ui" line="170"/>
        <location filename="../detailsdialog.ui" line="177"/>
        <location filename="../detailsdialog.ui" line="197"/>
        <source>-</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="227"/>
        <source>File size:</source>
        <translation>Размер файла:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="100"/>
        <source>Sample rate:</source>
        <translation>Дискретизация:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="19"/>
        <source>File path:</source>
        <translation>Путь к файлу:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="42"/>
        <source>Ogg Vorbis Info</source>
        <translation>Информация Ogg Vorbis</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="83"/>
        <source>Length:</source>
        <translation>Длительность:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="120"/>
        <source>Channels:</source>
        <translation>Каналов:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="143"/>
        <source>Bit Rate</source>
        <translation>Битовая частота</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="187"/>
        <source>Minimum:</source>
        <translation>Минимальная:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="204"/>
        <source>Maximum:</source>
        <translation>Максимальная:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="214"/>
        <source>Nominal:</source>
        <translation>Номинальная:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="246"/>
        <source>Ogg Vorbis Tag</source>
        <translation>Оgg Vorbis-тег</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="65"/>
        <location filename="../detailsdialog.cpp" line="67"/>
        <location filename="../detailsdialog.cpp" line="69"/>
        <source>kbps</source>
        <translation>Кб/с</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="70"/>
        <source>KB</source>
        <translation>КБ</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>Details</source>
        <translation>Информация</translation>
    </message>
</context>
</TS>
